@@ -1,24 +1,20 @@
 package Dist::Zilla::Plugin::TestRun;
 
-use 5.012;
+use 5.014;
 
 use Moose;
 
-our $VERSION = '0.0.2';
-
-with
-(
-    'Dist::Zilla::Role::TestRunner',
-);
+with( 'Dist::Zilla::Role::TestRunner', );
 
 sub test
 {
-    my ($self, $target) = @_;
+    my ( $self, $target ) = @_;
 
-    my $cmd = 'runtest';
+    my $cmd     = 'runtest';
     my @testing = $self->zilla->logger->get_debug ? '--verbose' : ();
 
-    system $^X, 'Build', $cmd, @testing and die "error running $^X Build $cmd\n";
+    system $^X, 'Build', $cmd, @testing
+        and die "error running $^X Build $cmd\n";
 }
 
 1;
@@ -31,11 +27,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::TestRun
+Dist::Zilla::Plugin::TestRun - run ./Build runtest on the build distribution
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -54,14 +50,6 @@ version 0.0.2
 
 Will run using "./Build runtest" as well.
 
-=head1 NAME
-
-Dist::Zilla::Plugin::TestRun - run ./Build runtest on the build distribution
-
-=head1 VERSION
-
-version 0.0.1
-
 =head1 SUBROUTINES/METHODS
 
 =head2 test()
@@ -73,38 +61,10 @@ Needed by L<Dist::Zilla> .
 Thanks to rwstauner and cjm on #distzilla on irc.perl.org for providing
 some help and insights.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2012 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Plugin-TestRun or by
-email to bug-dist-zilla-plugin-testrun@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Dist::Zilla::Plugin::TestRun
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -118,15 +78,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Dist-Zilla-Plugin-TestRun>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Dist-Zilla-Plugin-TestRun>
+L<https://metacpan.org/release/Dist-Zilla-Plugin-TestRun>
 
 =item *
 
@@ -134,31 +86,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Plugin-TestRun>
-
-=item *
-
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Dist-Zilla-Plugin-TestRun>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Dist-Zilla-Plugin-TestRun>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Dist-Zilla-Plugin-TestRun>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-TestRun>
 
 =item *
 
@@ -166,13 +94,13 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Dist-Zilla-Plugin-TestRun>
+L<http://cpants.cpanauthors.org/dist/Dist-Zilla-Plugin-TestRun>
 
 =item *
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/D/Dist-Zilla-Plugin-TestRun>
 
@@ -197,7 +125,7 @@ L<http://deps.cpantesters.org/?module=Dist::Zilla::Plugin::TestRun>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-dist-zilla-plugin-testrun at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dist-Zilla-Plugin-TestRun>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugin-TestRun>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -210,4 +138,27 @@ L<http://github.com/shlomif/perl-Dist-Zilla-Plugin-TestRun>
 
   git clone git://github.com/shlomif/perl-Dist-Zilla-Plugin-TestRun.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Plugin-TestRun> or by
+email to
+L<bug-dist-zilla-plugin-testrun@rt.cpan.org|mailto:bug-dist-zilla-plugin-testrun@rt.cpan.org>.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
